#
# Copyright 2016, Noah Kantrowitz
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# Just make sure the image launched and is reachable.
if os[:family] == 'windows'
  describe command('echo 1') do
    its(:exit_status) { is_expected.to eq 0 }
  end
else
  describe command('true') do
    its(:exit_status) { is_expected.to eq 0 }
  end
end
